==> haskell-vector-binary-instances-0.2.3.3-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-vector-binary-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-binary-instances
version: 0.2.3.3
id: vector-binary-instances-0.2.3.3-ITLfSosnCjgDHIm70KxMIu
key: vector-binary-instances-0.2.3.3-ITLfSosnCjgDHIm70KxMIu
license: BSD3
maintainer: dons00@gmail.com, bos@serpentine.com, Ben Gamari <ben@smart-cactus.org>
stability: Experimental
homepage: https://github.com/bos/vector-binary-instances
synopsis: Instances of Data.Binary and Data.Serialize for vector
description:
    Instances for Binary for the types defined in the vector package,
    making it easy to serialize vectors to and from disk. We use the
    generic interface to vectors, so all vector types are supported.
    Specific instances are provided for unboxed, boxed and storable
    vectors.
    .
    To serialize a vector:
    .
    > *Data.Vector.Binary> let v = Data.Vector.fromList [1..10]
    > *Data.Vector.Binary> v
    > fromList [1,2,3,4,5,6,7,8,9,10] :: Data.Vector.Vector
    > *Data.Vector.Binary> encode v
    > Chunk "\NUL\NUL\NUL\NUL\NUL...\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\n" Empty
    .
    Which you can in turn compress before writing to disk:
    .
    > compress . encode $ v
    > Chunk "\US\139\b\NUL\NUL\N...\229\240,\254:\NUL\NUL\NUL" Empty
category: Data
author: Don Stewart
exposed: True
exposed-modules:
    Data.Vector.Binary
abi: 27ad75ef1cd2328d2dcfa12bed885e22
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/vector-binary-instances-0.2.3.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/vector-binary-instances-0.2.3.3
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/vector-binary-instances-0.2.3.3
hs-libraries: HSvector-binary-instances-0.2.3.3-ITLfSosnCjgDHIm70KxMIu
depends:
    base-4.9.0.0 binary-0.8.3.0 vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-vector-binary-instances/html/vector-binary-instances.haddock
haddock-html: /usr/share/doc/haskell-vector-binary-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-binary-instances-0.2.3.4-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-vector-binary-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-binary-instances
version: 0.2.3.4
id: vector-binary-instances-0.2.3.4-5cD0L2W335u9PwXg62l6tz
key: vector-binary-instances-0.2.3.4-5cD0L2W335u9PwXg62l6tz
license: BSD3
maintainer: dons00@gmail.com, bos@serpentine.com, Ben Gamari <ben@smart-cactus.org>
stability: Experimental
homepage: https://github.com/bos/vector-binary-instances
synopsis: Instances of Data.Binary and Data.Serialize for vector
description:
    Instances for Binary for the types defined in the vector package,
    making it easy to serialize vectors to and from disk. We use the
    generic interface to vectors, so all vector types are supported.
    Specific instances are provided for unboxed, boxed and storable
    vectors.
    .
    To serialize a vector:
    .
    > *Data.Vector.Binary> let v = Data.Vector.fromList [1..10]
    > *Data.Vector.Binary> v
    > fromList [1,2,3,4,5,6,7,8,9,10] :: Data.Vector.Vector
    > *Data.Vector.Binary> encode v
    > Chunk "\NUL\NUL\NUL\NUL\NUL...\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\n" Empty
    .
    Which you can in turn compress before writing to disk:
    .
    > compress . encode $ v
    > Chunk "\US\139\b\NUL\NUL\N...\229\240,\254:\NUL\NUL\NUL" Empty
category: Data
author: Don Stewart
exposed: True
exposed-modules:
    Data.Vector.Binary
abi: 3392441b708bc5bcd46252ff06dc43a6
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/vector-binary-instances-0.2.3.4
library-dirs: /usr/lib/ghc-8.0.1/site-local/vector-binary-instances-0.2.3.4
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/vector-binary-instances-0.2.3.4
hs-libraries: HSvector-binary-instances-0.2.3.4-5cD0L2W335u9PwXg62l6tz
depends:
    base-4.9.0.0 binary-0.8.3.0 vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-vector-binary-instances/html/vector-binary-instances.haddock
haddock-html: /usr/share/doc/haskell-vector-binary-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
